# 基础功能
硬件基础功能

## 按键

``` python
from Cocopi import BUTTON
```

### 初始化

``` python
BUTTON(gpioid)
```

### 参数说明
| 参数 | 值 |描述 |
| :--- | :--- | :--- |
| gpioid | 数字 | 按键对应的引脚，必填，按键A引脚为14，按键B引脚为8，按键C引脚为13，按键D引脚为7。 |

会返回一个BUTTON，后续的操作都是BUTTON对象的操作

### 判断是否按下

``` python
BUTTON.is_pressed()
```

### 样例

``` python
from CocoPi import BUTTON

key_A = BUTTON(14)
key_B = BUTTON(8)
key_C = BUTTON(13)
key_D = BUTTON(7)

while True:
    time.sleep(1)
    if key_A.is_pressed():
        print('A被按下')
    elif key_B.is_pressed():
        print('B被按下')
    elif key_C.is_pressed():
        print('C被按下')
    elif key_D.is_pressed():
        print('D被按下')
    else:
        print("没有按键被按下")
```

## 温湿度

```python
from CocoPi import AHT20
```

### 初始化

```python
AHT20()
```

### 获取温度

```python
get_temperature()
```

### 获取湿度

```python
get_humidity()
```

### 样例

```python
from CocoPi import AHT20

tah = AHT20() # 初始化
while True:
    print(tah.get_temperature()) # 获取温度
    print(tah.get_humidity()) # 获取湿度
    time.sleep(1)
```
## 光照

```python
from CocoPi import LIGHTINTENSITY
```

### 初始化

```python
LIGHTINTENSITY()
```

### 获取光照强度

```python
value()
```

### 样例

```python
from CocoPi import LIGHTINTENSITY

light = LIGHTINTENSITY() # 初始化
while True:
    print(light.value()) # 获取光照强度
    time.sleep(1)
```
## 陀螺仪

```python
from cocopiPython import Gyroscope
```

### 初始化

```python
Gyroscope()
```

### 获取加速度

```python
get_acceleration(axis)
```

### 参数说明

| 参数 | 值 |描述 |
| :--- | :--- | :--- |
| axis | 字符串 | 表示三维空间中的方向，必填，"x"表示X轴，"y"表示Y轴，"z"表示Z轴。 |


### 获取倾斜角度

```python
get_tiltangle(axis)
```

### 参数说明

| 参数 | 值 |描述 |
| :--- | :--- | :--- |
| axis | 字符串 | 转动的方向，必填，"x"表示X轴，"y"表示Y轴。 |

### 样例

```python
from cocopiPython import Gyroscope
import time

Gyroscope = Gyroscope()
while True:
    print("加速度X："+str(Gyroscope.getAcceleration("x")))
    print("加速度Y："+str(Gyroscope.getAcceleration("y")))
    print("加速度Z："+str(Gyroscope.getAcceleration("z")))
    print("倾斜角度X："+str(Gyroscope.getAngularVelocity("x")))
    print("倾斜角度Y："+str(Gyroscope.getAngularVelocity("y")))
    time.sleep(1)
```
## 板载LED灯

``` python
from CocoPi import LED
```

### 初始化

``` python
LED = LED()
```

### 开关控制

``` python
LED.out(vaule)
```

### 参数说明
| 参数 | 值 |描述 |
| :--- | :--- | :--- |
| value | 数字 | 点亮和熄灭控制，必填，1表示点亮，0表示熄灭。 |



### 样例

``` python
from CocoPi import LED
import time

LED = LED() # 初始化
while True:
    LED.out(1) # 点亮
    time.sleep(1)
    LED.out(0) # 熄灭
    time.sleep(1)
```
## 录音

```python
from cocopiPython import Record
```

### 初始化

```python
Record()
```

### 开始录制

```python
start(time,path = "/root/user/audio/record.wav")
```

### 参数说明
|参数|值|描述|
|:---|:---|:---|
|time|整数|录制时间，必填|
|path|字符串|保存路径，选填，默认为/root/user/audio/record.wav|

### 停止录制

```python
stop()
```

### 样例

```python
from cocopiPython import Record

Record = Record() # 录制初始化

print("录音开始")

Record.start(4) # 开始录制

print("录音结束")
```

## 音频播放

```python
from cocopiPython import AudioPlay
```

### 初始化

```python
AudioPlay()
```

### 读取文件

```python
play_file(path)
```

### 参数说明
|参数|值|描述|
|:---|:---|:---|
|path|字符串|保存路径，选填，默认为/root/user/audio/record.wav|

### 设置音量

```python
setVolume(volume)
```

### 参数说明
|参数|值|描述|
|:---|:---|:---|
|volume|整数|音量，0～100，必填|

### 开始播放

```python
play()
```

### 结束播放

```python
stop()
```

### 样例

```python
from cocopiPython import AudioPlay

audio = AudioPlay() # 播放初始化
audio.setVolume(100) # 设置音量
audio.play_file("/root/user/audio/record.wav") # 音频文件
while True:
    audio.play() # 播放
```
## 视频播放

```python
from cocopiPython import VideoPlay
```

### 初始化

```python
VideoPlay()
```

### 读获取视频文件

```python
setVideoPath(path)
```

### 参数说明
|参数|值|描述|
|:---|:---|:---|
|path|字符串|保存路径，必填|

### 播放帧

```python
start(i)
```

### 参数说明
|参数|值|描述|
|:---|:---|:---|
|i|视频帧|视频文件的视频帧，必填|


### 样例

```python
from cocopiPython import VideoPlay

video = VideoPlay()
while True:
    print("start")
    for i in video.setVideoPath("/root/preset/video/output_240_240.mp4"):
        video.start(i)
    print("end")
```
